@@ -7,11 +7,13 @@ from sqlalchemy import or_, Column
 
 from flask import flash
 
+from flask.ext.admin.tools import ObsoleteAttr
 from flask.ext.admin.babel import gettext, ngettext, lazy_gettext
 from flask.ext.admin.model import BaseModelView
 from flask.ext.admin.actions import action
 
 from flask.ext.admin.contrib.sqlamodel import form, filters, tools
+from .typefmt import DEFAULT_FORMATTERS
 
 
 class ModelView(BaseModelView):
@@ -24,12 +26,16 @@ class ModelView(BaseModelView):
             admin.add_view(ModelView(User, db.session))
     """
 
-    hide_backrefs = True
+    column_hide_backrefs = ObsoleteAttr('column_hide_backrefs',
+                                        'hide_backrefs',
+                                        True)
     """
         Set this to False if you want to see multiselect for model backrefs.
     """
 
-    auto_select_related = True
+    column_auto_select_related = ObsoleteAttr('column_auto_select_related',
+                                              'auto_select_related',
+                                              True)
     """
         Enable automatic detection of displayed foreign keys in this view
         and perform automatic joined loading for related models to improve
@@ -40,30 +46,36 @@ class ModelView(BaseModelView):
         will still make separate database call.
     """
 
-    list_select_related = None
+    column_select_related_list = ObsoleteAttr('column_select_related',
+                                             'list_select_related',
+                                              None)
     """
-        List of parameters for SQLAlchemy `subqueryload`. Overrides `auto_select_related`
+        List of parameters for SQLAlchemy `subqueryload`. Overrides `column_auto_select_related`
         property.
 
         For example::
 
             class PostAdmin(ModelAdmin):
-                list_select_related = ('user', 'city')
+                column_select_related_list = ('user', 'city')
 
         You can also use properties::
 
             class PostAdmin(ModelAdmin):
-                list_select_related = (Post.user, Post.city)
+                column_select_related_list = (Post.user, Post.city)
 
         Please refer to the `subqueryload` on list of possible values.
     """
 
-    list_display_all_relations = False
+    column_display_all_relations = ObsoleteAttr('column_display_all_relations',
+                                                'list_display_all_relations',
+                                                False)
     """
         Controls if list view should display all relations, not only many-to-one.
     """
 
-    searchable_columns = None
+    column_searchable_list = ObsoleteAttr('column_searchable_list',
+                                          'searchable_columns',
+                                          None)
     """
         Collection of the searchable columns. Only text-based columns
         are searchable (`String`, `Unicode`, `Text`, `UnicodeText`).
@@ -71,12 +83,12 @@ class ModelView(BaseModelView):
         Example::
 
             class MyModelView(ModelView):
-                searchable_columns = ('name', 'email')
+                column_searchable_list = ('name', 'email')
 
         You can also pass columns::
 
             class MyModelView(ModelView):
-                searchable_columns = (User.name, User.email)
+                column_searchable_list = (User.name, User.email)
 
         Following search rules apply:
 
@@ -182,8 +194,30 @@ class ModelView(BaseModelView):
 
             class MyModelView(ModelView):
                 inline_models = (MyInlineModelForm(MyInlineModel),)
+
+        You can customize generated field name by:
+
+        1. Using `form_name` property as option:
+
+            class MyModelView(ModelView):
+                inline_models = ((Post, dict(form_label='Hello')))
+
+        2. Using forward relation name and `column_labels` property:
+
+            class Model1(Base):
+                pass
+
+            class Model2(Base):
+                # ...
+                model1 = relation(Model1, backref='models')
+
+            class MyModel1View(Base):
+                inline_models = (Model2,)
+                column_labels = {'models': 'Hello'}
     """
 
+    column_type_formatters = DEFAULT_FORMATTERS
+
     def __init__(self, model, session,
                  name=None, category=None, endpoint=None, url=None):
         """
@@ -218,10 +252,10 @@ class ModelView(BaseModelView):
             raise Exception('Model %s does not have primary key.' % self.model.__name__)
 
         # Configuration
-        if not self.list_select_related:
+        if not self.column_select_related_list:
             self._auto_joins = self.scaffold_auto_joins()
         else:
-            self._auto_joins = self.list_select_related
+            self._auto_joins = self.column_select_related_list
 
     # Internal API
     def _get_model_iterator(self, model=None):
@@ -253,14 +287,9 @@ class ModelView(BaseModelView):
         columns = []
 
         for p in self._get_model_iterator():
-            # Filter by name
-            if (self.excluded_list_columns and
-                p.key in self.excluded_list_columns):
-                continue
-
             # Verify type
             if hasattr(p, 'direction'):
-                if self.list_display_all_relations or p.direction.name == 'MANYTOONE':
+                if self.column_display_all_relations or p.direction.name == 'MANYTOONE':
                     columns.append(p.key)
             elif hasattr(p, 'columns'):
                 # TODO: Check for multiple columns
@@ -269,7 +298,7 @@ class ModelView(BaseModelView):
                 if column.foreign_keys:
                     continue
 
-                if not self.list_display_pk and column.primary_key:
+                if not self.column_display_pk and column.primary_key:
                     continue
 
                 columns.append(p.key)
@@ -297,7 +326,7 @@ class ModelView(BaseModelView):
                 if column.foreign_keys:
                     continue
 
-                if not self.list_display_pk and column.primary_key:
+                if not self.column_display_pk and column.primary_key:
                     continue
 
                 columns[p.key] = column
@@ -321,6 +350,9 @@ class ModelView(BaseModelView):
 
         return attr.property.columns
 
+    def _need_join(self, table):
+        return table not in self.model._sa_class_manager.mapper.tables
+
     def init_search(self):
         """
             Initialize search. Returns `True` if search is supported for this
@@ -329,11 +361,11 @@ class ModelView(BaseModelView):
             For SQLAlchemy, this will initialize internal fields: list of
             column objects used for filtering, etc.
         """
-        if self.searchable_columns:
+        if self.column_searchable_list:
             self._search_fields = []
             self._search_joins = dict()
 
-            for p in self.searchable_columns:
+            for p in self.column_searchable_list:
                 for column in self._get_columns_for_field(p):
                     column_type = type(column.type).__name__
 
@@ -344,10 +376,10 @@ class ModelView(BaseModelView):
                     self._search_fields.append(column)
 
                     # If it belongs to different table - add a join
-                    if column.table != self.model.__table__:
+                    if self._need_join(column.table):
                         self._search_joins[column.table.name] = column.table
 
-        return bool(self.searchable_columns)
+        return bool(self.column_searchable_list)
 
     def is_text_column_type(self, name):
         """
@@ -391,7 +423,9 @@ class ModelView(BaseModelView):
                                                         visible_name)
 
                     if flt:
-                        self._filter_joins[column.table.name] = column.table
+                        if self._need_join(column.table):
+                            self._filter_joins[column.table.name] = column.table
+
                         filters.extend(flt)
 
             return filters
@@ -415,7 +449,7 @@ class ModelView(BaseModelView):
 
             if flt:
                 # If there's relation to other table, do it
-                if column.table != self.model.__table__:
+                if self._need_join(column.table):
                     self._filter_joins[column.table.name] = column.table
 
             return flt
@@ -437,7 +471,7 @@ class ModelView(BaseModelView):
         converter = self.model_form_converter(self.session, self)
         form_class = form.get_form(self.model, converter,
                           only=self.form_columns,
-                          exclude=self.excluded_form_columns,
+                          exclude=self.form_excluded_columns,
                           field_args=self.form_args)
 
         if self.inline_models:
@@ -453,7 +487,7 @@ class ModelView(BaseModelView):
                 Form class
         """
         converter = self.model_form_converter(self.session, self)
-        inline_converter = self.inline_model_form_converter(self.session)
+        inline_converter = self.inline_model_form_converter(self.session, self)
 
         for m in self.inline_models:
             form_class = inline_converter.contribute(converter,
@@ -468,10 +502,17 @@ class ModelView(BaseModelView):
             Return list of joined tables by going through the
             displayed columns.
         """
+        if not self.column_auto_select_related:
+            return []
+
         relations = set()
 
         for p in self._get_model_iterator():
             if hasattr(p, 'direction'):
+                # Check if it is pointing to same model
+                if p.mapper.class_ == self.model:
+                    continue
+
                 if p.direction.name == 'MANYTOONE':
                     relations.add(p.key)
 
